<?php
/*
Plugin Name: Total Slider
Plugin URI: http://www.totalslider.com/
Description: The best experience for building sliders, with true WYSIWYG, drag & drop and more!
Version: 1.1.3
Author: Peter Upfold
Author URI: http://www.vanpattenmedia.com/
License: GPLv2 or later
License URI: https://www.gnu.org/licenses/gpl-2.0.html
Text Domain: total_slider
/* ----------------------------------------------*/

/*  Copyright (C) 2011-2013 Peter Upfold.

    This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/


define( 'TOTAL_SLIDER_IN_FUNCTIONS', true );
define( 'TOTAL_SLIDER_REQUIRED_CAPABILITY', 'total_slider_manage_slides' );
define( 'TOTAL_SLIDER_MAX_SLIDE_GROUPS', 24 );
define( 'TOTAL_SLIDER_DEFAULT_CROP_WIDTH', 600 );
define( 'TOTAL_SLIDER_DEFAULT_CROP_HEIGHT', 300 );
define( 'TOTAL_SLIDER_DATAFORMAT_VERSION', '1.1' );

/*VPM_33x_CONDITIONAL*/
if ( ! version_compare( get_bloginfo('version'), '3.4', '>=' ) ) {
	define( 'TOTAL_SLIDER_33x_WORKAROUND', true );
}


require_once( dirname(__FILE__) . '/includes/class.total-slide-group.php' );
require_once( dirname(__FILE__) . '/includes/class.total-slider-template.php' ); //TODO efficiency -- conditional on 'page'? What about the widget?

$TS_The_Slug = false;
$TS_The_Template = false;
$TS_The_Tpl_Error = false;

/******************************************** Total_Slider main class ********************************************/

class Total_Slider {


	/* data structure

		a serialized array stored as a wp_option


		total_slider_slides_[slug]

			[0]
				id				[string] (generated by str_replace('.', '_', uniqid('', true)); )
				title			[string]
				description		[string]
				background		[string]
				link			[string]
				title_pos_x		[int]
				title_pos_y		[int]

			[1]
				id				[string] (generated by str_replace('.', '_', uniqid('', true)); )
				title			[string]
				description		[string]
				background		[string]
				link			[string]
				title_pos_x		[int]
				title_pos_y		[int]

			[2] ...

	*/

	/***********	// !Registration, first-time, etc.	***********/

	public static function create_slides_option_field() {
	/*
		Upon plugin activation, creates the total_slider_slide_groups option
		in wp_options, if it does not already exist.

		Also set up a base capability for administrator to access the Slider
		Admin page, and configure some default general options.
	*/
	
		global $current_user;
	
		$no_slide_groups = false;

		if ( ! get_option('total_slider_slide_groups') ) {
			$no_slide_groups = true;
			add_option( 'total_slider_slide_groups', array( ) ); // create with a blank array

		}

		// set the capability for administrator so they can visit the options page
		$admin = get_role('administrator');
		$admin->add_cap( TOTAL_SLIDER_REQUIRED_CAPABILITY );
		
		get_currentuserinfo();
		
		// ensure that the current user can manage the plugin once installed (references #49)
		if ( current_user_can('install_plugins') ) {
			$current_user->add_cap( TOTAL_SLIDER_REQUIRED_CAPABILITY );
		}

		// set up default general options

		if ( ! get_option('total_slider_general_options') )
		{
			add_option( 'total_slider_general_options', array(
				'should_enqueue_template'	=> 	'1',
				'should_show_tinymce_button' => '1'
			) );
		}
		
		
		/* Do not create the data format version if we are upgrading from v1.0.x, but upgrade() hasn't been called --
		   for example, the plugin has been removed and reactivated.
		   In this instance, we should run upgrade(), which will set the data format version and run other upgrade
		   tasks.
		*/
		if ( ! get_option('total_slider_dataformat_version') && !$no_slide_groups ) {
			return Total_Slider::upgrade();
		}
		
		if ( ! get_option('total_slider_dataformat_version') ) {
			add_option( 'total_slider_dataformat_version', TOTAL_SLIDER_DATAFORMAT_VERSION );
		}

	}
	
	public static function upgrade() {
	/*
		Check to see if an upgrade to Total Slider's data format is required, and if
		so, kick off the appropriate code to run the upgrade.
	*/
	
		if ( ! get_option('total_slider_dataformat_version') ) {
			// Total Slider has not been data-upgraded since before the version was introduced (1.0.x)
			
			// run an upgrade
			require_once( dirname(__FILE__) . '/includes/upgrade/v1.0.x-to-v1.1.php' );	
			
		}
		// eventually, there will be additional conditionals here for various incremental upgrade scenarios (version_compare??)
	
	}

	public static function register_as_widget() {
	/*
		Register the output to the theme as a widget
	*/

		register_widget( 'Total_Slider_Widget' );

	}

	public static function load_text_domain() {
	/*
		Load the GetText domain for this plugin's translatable strings.
	*/

		load_plugin_textdomain( 'total_slider', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );

	}

	/***********	Utility Functions	***********/

	public static function sanitize_slide_group_slug( $slug ) {
	/*
		Sanitize a slide group slug, for accessing the wp_option row with that slug name.

		A wp_option name cannot be greater than 64 chars, so we truncate after 42 chars (63 - length of our option prefix),
		so as not to request a too-long wp_option name from MySQL.

		The create routine will handle if there is an existig name conflict due to the truncation.

	*/
		return substr ( preg_replace( '/[^a-zA-Z0-9_\-]/', '', $slug ), 0, ( 63 - strlen('total_slider_slides_' ) ) );
	}

	private function get_current_slides( $slug ) {
	/*
		Returns an array of the current slides in the database, in their
		current precedence order.
	*/
		return get_option( 'total_slider_slides_' . Total_Slider::sanitize_slide_group_slug($slug) );
	}

	private function id_filter( $id_to_filter ) {
	/*
		Filter a uniqid string for output to the admin interface HTML.
	*/

		return preg_replace( '[^0-9a-zA-Z_]', '', $id_to_filter );

	}

	public static function ugly_js_redirect( $location, $data = false ) {
	/*
		Redirect, from within the admin panel for this plugin back to the plugin's main page.
	*/

		switch ( $location ) {

			case 'root':
				$url = 'admin.php?page=total-slider';
			break;

			case 'edit-slide-group':
				$url = 'admin.php?page=total-slider&group=';
				$url .= esc_attr(Total_Slider::sanitize_slide_group_slug($data));
			break;

			default:
				$url = 'admin.php?page=total-slider';
			break;

		}

		// erm, just a little bit of an ugly hack :(

		?><script type="text/javascript">window.location.replace('<?php echo $url; ?>');</script>
		<noscript><h1><a href="<?php echo esc_url($url); ?>"><?php _e( 'Please visit this page to continue', 'total_slider' ); ?></a></h1></noscript><?php
		die();

	}
	
	public static function determine_template()	{
	/*
		Determine which template we should use, and its location, from the slide group's template
		attribute.
	*/
	
		global $TS_The_Slug, $TS_The_Template, $TS_The_Tpl_Error;
		
		if ( $TS_The_Template ) {
			return $TS_The_Template;
		}
		
		if ( ! $TS_The_Slug ) {
			if ( ! array_key_exists ('group', $_GET ) ) {
				return false;
			}
			
			$TS_The_Slug = Total_Slider::sanitize_slide_group_slug( $_GET['group'] );
		}
		
		$slide_group = new Total_Slide_Group($TS_The_Slug);
		
		if ( ! $slide_group->load() ) {
			return false;
		}
		
		$slug = $slide_group->template;
		$location = $slide_group->templateLocation;
		
		try {
			$TS_The_Template = new Total_Slider_Template( $slug, $location );
		}
		catch (Exception $e) {
			$TS_The_Tpl_Error = $e;
		}
		
		return $TS_The_Template;
		
	}

	public static function set_capability_for_roles( $roles_to_set) {
	/*
		Set the TOTAL_SLIDER_REQUIRED_CAPABILITY capability against this role, so this WordPress
		user role is able to manage the slides.

		Will clear out the capability from all roles, then add it to both administrator and the
		specified roles. (Administrator always has access).
	*/
		global $wp_roles;

		if ( ! current_user_can( 'manage_options' ) ) {
			return false;
		}

		$all_roles = get_editable_roles();
		$valid_roles = array_keys( $all_roles );

		if ( ! is_array( $all_roles ) || count( $all_roles ) < 1 ) {
			return false;
		}

		// clear the capability from all roles first
		foreach ( $all_roles as $r_name => $r ) {
			$wp_roles->remove_cap( $r_name, TOTAL_SLIDER_REQUIRED_CAPABILITY );
		}

		// add the capability to 'administrator', which can always manage slides
		$wp_roles->add_cap( 'administrator', TOTAL_SLIDER_REQUIRED_CAPABILITY );

		// add the capability to the specified $roles_to_set
		if ( is_array( $roles_to_set ) && count( $roles_to_set ) > 0 ) {
			
			foreach($roles_to_set as $the_role) {
				if ( in_array( $the_role, $valid_roles ) ) {
					$wp_roles->add_cap( $the_role, TOTAL_SLIDER_REQUIRED_CAPABILITY );
				}
			}
		}

		return true;

	}
	
	public static function shortcode_handler($atts, $content, $tag) {
	/*
		Create a Total Slider WP_Widget from a [totalslider] shortcode in
		the post body.
	*/
	
		extract( shortcode_atts( array(
			'group' => NULL
		), $atts ));
		
		// require a slide group
		if ( empty($group) ) {
			return __( '<strong>Total Slider:</strong> No slide group selected to show.', 'total_slider' );
		}
		
		// require a valid slide group
		if ( ! get_option( 'total_slider_slides_' . Total_Slider::sanitize_slide_group_slug( $group ) ) )
		{
			return __( '<strong>Total Slider:</strong> Could not find the selected slide group to show. Does it still exist?', 'total_slider' );
		}
		
		ob_start();
		
		the_widget( 'Total_Slider_Widget', array(
											'groupSlug' => Total_Slider::sanitize_slide_group_slug($group)
											) );
		
		$output = ob_get_contents();
		ob_end_clean();
		
		return $output;
	
	}

	/***********	// !Control passing, runtime UI setup, enqueuing etc.	***********/

	public static function pass_control_to_ajax_handler() {
	/*
		If the user is trying to perform an Ajax action, immediately pass
		control over to ajax_interface.php.

		This should hook admin_init() (therefore be as light as possible).
	*/

		if (
			array_key_exists( 'page', $_GET ) &&
			'total-slider' == $_GET['page'] &&
			array_key_exists( 'total-slider-ajax', $_GET ) &&
			'true' == $_GET['total-slider-ajax']
		) {
			require_once( dirname(__FILE__) . '/includes/ajax_interface.php' );
		}

	}

	public static function add_admin_submenu() {
	/*
		Add the submenu to the admin sidebar for the configuration screen.
	*/
		if ( array_key_exists( 'page', $_GET ) && 'total-slider' == $_GET['page'] )
		{
		
			// this is a convenient point to upgrade our database if necessary
			Total_Slider::upgrade();
					
			// load .js if SCRIPT_DEBUG is true, or load .min.js otherwise
			$maybe_min = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : 'min.' ;
			
			wp_register_script(
			
				'total-slider-ejs', 										/* handle */
				plugin_dir_url( __FILE__ ).'js/ejs.' . $maybe_min . 'js',	/* src */
				array(
					'jquery', 'jquery-ui-draggable', 'jquery-ui-droppable',
					'jquery-ui-sortable'
				),															/* deps */
				date("YmdHis", @filemtime( plugin_dir_path( __FILE__ ) .
							'js/ejs.' . $maybe_min . 'js'	) ),			/* ver */
				true														/* in_footer */		
			);


			// get our JavaScript on
			wp_register_script(
			
				'total-slider-interface', 									/* handle */
				plugin_dir_url( __FILE__ ).'js/interface.' . $maybe_min . 'js',/* src */
				array(
					'jquery', 'jquery-ui-draggable', 'jquery-ui-droppable',
					'jquery-ui-sortable', 'total-slider-ejs'
				),															/* deps */
				date("YmdHis", @filemtime( plugin_dir_path( __FILE__ ) .
							'js/interface.' . $maybe_min . 'js'	) ),		/* ver */
				true														/* in_footer */		
			);
			
			
			wp_enqueue_script( 'jquery' );

			wp_enqueue_script( 'wp-ajax-response' );

			wp_enqueue_script( 'media' );
			wp_enqueue_script( 'media-upload' );
			wp_enqueue_script( 'thickbox' );
			wp_enqueue_style( 'thickbox' );

			if ( function_exists( 'wp_enqueue_media' ) ) {
				wp_enqueue_media();
			}

			wp_enqueue_script( 'postbox' );

			wp_enqueue_script( 'jquery-ui-draggable' );
			wp_enqueue_script( 'jquery-ui-droppable' );
			wp_enqueue_script( 'jquery-ui-sortable' );

			wp_enqueue_style( 'wp-pointer' );
			wp_enqueue_script( 'wp-pointer' );
			
			wp_enqueue_script( 'total-slider-ejs' );
			
			wp_enqueue_script( 'total-slider-interface' );

			wp_localize_script( 'total-slider-interface', '_total_slider_L10n', Total_Slider::js_l10n() );	

			wp_register_style( 'total-slider-interface-styles', plugin_dir_url( __FILE__ ) . 'css/interface.css' );
			wp_enqueue_style( 'total-slider-interface-styles' );
			
			// enqueue the frontend so that the interface will be ready
			Total_Slider::enqueue_slider_frontend( 'backend' );	

			// load the WP_Pointer if we are on the Slides page
			if ( array_key_exists ('group', $_GET ) ) {
				add_action( 'admin_print_footer_scripts', array('Total_Slider', 'print_help_pointer_js') );
			}

		}

		/* Top-level menu page */
		add_menu_page(

			__( 'Slider', 'total_slider' ),									/* title of options page */
			__( 'Slider', 'total_slider' ),									/* title of options menu item */
			TOTAL_SLIDER_REQUIRED_CAPABILITY,								/* permissions level */
			'total-slider',													/* menu slug */
			array( 'Total_Slider', 'print_slide_groups_page' ),				/* callback to print the page to output */
			plugin_dir_url( __FILE__ ) . 'img/total-slider-icon-16.png',	/* icon file */
			null 															/* menu position number */
		);

		/* First child, 'Slide Groups' */
		$submenu = add_submenu_page(

			'total-slider',										/* parent slug */
			__( 'Slide Groups', 'total_slider' ),				/* title of page */
			__( 'Slide Groups', 'total_slider' ),				/* title to use in menu */
			TOTAL_SLIDER_REQUIRED_CAPABILITY,					/* permissions level */
			'total-slider',										/* menu slug */
			array( 'Total_Slider', 'print_slide_groups_page' )	/* callback to print the page to output */

		);

		/* 'Settings' */
		add_submenu_page(

			'total-slider',										/* parent slug */
			__( 'Settings', 'total_slider' ),					/* title of page */
			__( 'Settings', 'total_slider' ),					/* title to use in menu */
			TOTAL_SLIDER_REQUIRED_CAPABILITY,					/* permissions level */
			'total-slider-settings',							/* menu slug */
			array('Total_Slider', 'print_settings_page')		/* callback to print the page to output */

		);

		add_action( 'admin_head-'. $submenu, array('Total_Slider', 'add_slides_help') );


	}

	public static function print_help_pointer_js() {
	/*
		Print the help pointer JavaScript.
	*/

		require( dirname( __FILE__ ) . '/admin/support/help-pointer-js.php' );

	}
	
	public static function print_js_admin_page_reference() {
	/*
		When WordPress is displaying the WP-Admin page headers, add a reference to the
		ajax_interface.php access URL, so we can pass it to TinyMCE popup iframes.
	*/

		require( dirname( __FILE__ ) . '/admin/support/js-admin-page-reference.php' );	
	
	}

	public static function enqueue_slider_frontend( $context = 'frontend' )	{
	/*
		When WordPress is enqueueing the styles, inject our slider CSS and JavaScript in. We will use the Template Manager
		to canonicalize the URIs and paths for the JS and CSS (including .min.js etc.), and simply enqueue what it tells us to here.

		If $context is 'backend', we will load the CSS only and not the JS.

	*/
	
		global $TS_The_Template;
	
		// load .min.js if available, if SCRIPT_DEBUG is not true in wp-config.php
		$is_min = ( defined('SCRIPT_DEBUG') && SCRIPT_DEBUG ) ? false : true;

		$general_options = get_option( 'total_slider_general_options' );

		// do not run if enqueue is disabled
		if (
			is_array($general_options) &&
			array_key_exists( 'should_enqueue_template', $general_options ) &&
			'0' == $general_options['should_enqueue_template'] &&
			$context != 'backend'
		) {
			return false;
		}
		
		if ( ! $TS_The_Template || ! is_a( $TS_The_Template, 'Total_Slider_Template' ) )
		{	
			// determine the current template
			if ( ! Total_Slider::determine_template() )	{
				return false;		
			}
		}
		
		// load the CSS
		wp_register_style(		
			'total-slider-frontend',										/* handle */
			$TS_The_Template->css_uri(),									/* src */
			array(),														/* deps */
			date( 'YmdHis', @filemtime($TS_The_Template->css_path() ) ),	/* ver */
			'all'															/* media */
		);
		
		wp_enqueue_style( 'total-slider-frontend' );
		
		if ( 'backend' != $context ) {
			if ($is_min) {
				$js_uri = $TS_The_Template->js_min_uri();
				$js_path = $TS_The_Template->js_min_path();				
			}
			else {
				$js_uri = $TS_The_Template->js_uri();
				$js_path = $TS_The_Template->js_path();				
			}
			
			// enqueue the JS
			
			wp_register_script(	
				'total-slider-frontend',										/* handle */
				$js_uri,														/* src */
				array( 'jquery' ),												/* deps */
				date( 'YmdHis', @filemtime($jsPath) ),							/* ver */
				true															/* in_footer */					
			);
			
			wp_enqueue_script( 'total-slider-frontend' );
			
		}		

	}

	public static function add_slides_help() {
	/*
		Add our help tab to the Slides page.
	*/

		require( dirname( __FILE__ ) . '/admin/support/help.php' );

	}

	public static function js_l10n()
	{
	/*
		Return the object containing all of the i18n-capable and l10n-capable
		strings in the interface.js file, ready for wp_localize_script.
	*/

		return array (

			'switchEditWouldLoseChanges'	=> __( "You are still editing the current slide. Switching to a different slide will lose your changes.\n\nDo you want to lose your changes?", 'total_slider' ),
			'leavePageWouldLoseChanges'		=> __( 'You are still editing the current slide. Leaving this page will lose your changes.', 'total_slider' ),
				/* note:
					This message may or may not be shown. This is browser-dependent. All we can do in some cases is throw a generic
					“don’t leave, you haven’t saved yet” confirm box, which is better than nothing.
				*/
			'wouldLoseUnsavedChanges'		=> __( "You will lose any unsaved changes.\n\nAre you sure you want to lose these changes?", 'total_slider' ),
			'confirmDeleteOperation'		=> __( "Are you sure you want to delete this slide?\n\nThis action cannot be undone.", 'total_slider' ),
			'validationErrorIntroduction'		=> __( "Please correct the following errors with the form.\n\n", 'total_slider' ),
			'validationNoSlideTitle'		=> __( 'You must enter a slide title.', 'total_slider' ),
			'validationNoSlideDescription'		=> __( 'You must enter a slide description.', 'total_slider' ),
			'validationInvalidBackgroundURL'	=> __( 'The supplied background image URL is not a valid URL.', 'total_slider' ),
			'validationInvalidLinkURL'		=> __( 'The supplied external link is not a valid URL.', 'total_slider' ),
			'validationInvalidLinkID'		=> __( 'The supplied post ID for the slide link is not valid.', 'total_slider' ),
			'sortWillSaveSoon'			=> __( 'The new order will be saved when you save the new slide.', 'total_slider' ),
			'unableToResortSlides'			=> __( 'Sorry, unable to resort the slides.', 'total_slider' ),
			'newSlideTemplateUntitled'		=> __( 'untitled', 'total_slider' ),
			'newSlideTemplateNoText'		=> __( '(no text)', 'total_slider' ),
			'newSlideTemplateMove'			=> __( 'Move', 'total_slider' ),
			'newSlideTemplateDelete'		=> __( 'Delete', 'total_slider' ),
			'slideEditNoPostSelected'		=> __( 'No post selected.', 'total_slider' ),
			'saveButtonValue'			=> __( 'Save', 'total_slider' ),
			'unableToGetSlide'			=> __( 'Sorry, unable to get that slide', 'total_slider' ),
			'slideSaved'				=> __( 'Slide saved.', 'total_slider' ),
			'uploadSlideBgImage'			=> __( 'Upload slide background image', 'total_slider' ),
			'unableToSaveSlide'			=> __( 'Sorry, unable to save the new slide.', 'total_slider' ),
			'unableToDeleteSlideNoID'		=> __( 'Unable to delete -- could not get the slide ID for the current slide.', 'total_slider' ),
			'unableToDeleteSlide'			=> __( 'Sorry, unable to delete the slide.', 'total_slider' ),
			'templateChangeWouldLoseData'		=> __( "Changing the template affects all slides in this group.\n\nAny custom positions for the title and description will be lost. You should review your slides after the change.\n\nDo you want to change the template?", 'total_slider' ),
			'mustFinishEditingFirst'		=> __( 'You must finish editing the slide before performing this action. Please either save your changes to the slide, or click Cancel.', 'total_slider' ),
			'uploadSlideBgButtonText'		=> __( 'Use as background image', 'total_slider' ),
			
		);

	}
	
	public static function bootstrap_tinymce_plugin() {
	/*
		Bootstrap the setup of the Total Slider insert button on the rich text
		editing toolbar, if enabled and desired.
	*/
	
		if ( !current_user_can('edit_posts') &&  ! current_user_can('edit_pages') )
		{
			return;
		}
		
		if ( 'true' == get_user_option( 'rich_editing' ) ) {
		
			// check option to see if we should add the button to the toolbar or not
			$general_options = get_option( 'total_slider_general_options' );
			
			if (
				is_array($general_options) &&
				array_key_exists('should_show_tinymce_button', $general_options) &&
				'1' == $general_options['should_show_tinymce_button']
			) {
				add_filter( 'mce_external_plugins', array( 'Total_Slider', 'register_tinymce_plugin' ) );
				add_filter( 'mce_buttons', array( 'Total_Slider', 'register_tinymce_button' ) );			
			}
		}

		add_action( 'admin_head', array( 'Total_Slider', 'print_js_admin_page_reference' ) );
		// we should always load the JS admin page reference -- see #58 at https://github.com/vanpattenmedia/total-slider/issues/58
	
	}
	
	public static function register_tinymce_plugin( $plugin_array ) {
	/*
		Register our TinyMCE plugin JavaScript, so it can be run by TinyMCE.
	*/
		$plugin_array['total_slider_insert'] = plugin_dir_url( __FILE__ ) . 'tinymce-custom/mce/total_slider_insert/editor_plugin.js';
		return $plugin_array;
		
	}
	
	public static function register_tinymce_button ( $buttons ) {
	/*
		Add our new Total Slider button to the TinyMCE buttons toolbar.
	*/	
		array_push( $buttons, 'separator', 'total_slider_insert' );
		return $buttons;
				
	}

	/***********	// !Print functions for each plugin admin page	***********/

	public static function print_slide_groups_page() {
	/*
		Print the page for adding, deleting Slide Groups and for pushing people over
		to the 'actual' slides editing interface for that Slide Group.
	*/
	
		global $allowed_template_locations;

		require( dirname( __FILE__ ) . '/admin/slide-groups.php' );

	}

	public static function print_slides_page() {
	/*
		Print the actual slides page for adding, editing and removing the slides.
	*/

		global $TS_The_Slug, $TS_The_Tpl_Error, $allowed_template_locations, $TS_The_Template;

		require( dirname( __FILE__ ) . '/admin/slides.php' );

	}



	public static function print_settings_page() {
	/*
		Print the settings page to output, and also handle any of the Settings forms if they
		have come back to us.
	*/

		require( dirname( __FILE__ ) . '/admin/settings.php' );

	}

	public static function print_uploader_javascript() {
	/*
		Print the JavaScript to inject into the Media Uploader
	*/

		require( dirname( __FILE__ ) . '/admin/support/uploader-javascript.php' );

	}

	/***********	// !Metabox printer callbacks	***********/

	public static function print_credits_metabox()
	{
	/*
		Print to output the contents of the credits/notes metabox.
	*/

		require( dirname( __FILE__) . '/admin/metaboxes/credits.php' );

	}

	public static function print_slide_sorter_metabox() {
	/*
		Print to output the contents of the slide sorter/slide listing metabox.
	*/

		global $TS_The_Slug;

		require( dirname( __FILE__ ) . '/admin/metaboxes/slide-sorter.php' );

	}
	
	public static function print_slide_template_metabox() {
	/*
		Print to output the contents of the slide template metabox.
	*/
	
		global $TS_The_Slug;
	
		if ( ! $TS_The_Slug ) {
			if ( ! array_key_exists('group', $_GET ) )
			{
				return false;
			}
			
			$TS_The_Slug = Total_Slider::sanitize_slide_group_slug( $_GET['group'] );
		}
		
		$slide_group = new Total_Slide_Group( $TS_The_Slug );
		if ( ! $slide_group->load() ) {
			return false;
		}
	
		?><div id="template-switch-controls">
			<p>
			<?php $t = new Total_Slider_Template_Iterator(); ?>
				<select name="template-slug" id="template-slug-selector">
					
					<?php $builtin = $t->discover_templates( 'builtin' ); ?>
					<?php if ( is_array( $builtin ) && count( $builtin ) > 0 ): ?>
					<optgroup label="<?php _e( 'Built-in', 'total_slider' ); ?>">
						<?php foreach( $builtin as $tpl ): ?>

							<option
								value="<?php echo esc_attr( $tpl['slug'] ); ?>"
								<?php if ( 'builtin' == $slide_group->templateLocation && $slide_group->template == $tpl['slug'] ): ?>
								selected="selected"
								<?php endif; ?>
								
							><?php echo esc_html( $tpl['name'] );?></option>
						<?php endforeach; ?>
					</optgroup>
					<?php endif; ?>
					
					<?php $theme = $t->discover_templates( 'theme' ); ?>
					<?php if ( is_array( $theme ) && count( $theme ) > 0 ): ?>
					<optgroup label="<?php _e( 'Theme', 'total_slider' ); ?>">
						<?php foreach( $theme as $tpl ): ?>
							<option
								value="<?php echo esc_attr( $tpl['slug'] ); ?>"
								<?php if ('theme' == $slide_group->templateLocation && $slide_group->template == $tpl['slug']): ?>
								selected="selected"
								<?php endif; ?>
								
							><?php echo esc_html( $tpl['name'] );?></option>
						<?php endforeach; ?>
					</optgroup>
					<?php endif; ?>
					
					<?php $legacy = $t->discover_templates( 'legacy', false ); ?>
					<?php if ( is_array( $legacy ) && count( $legacy ) > 0 ): ?>
					<optgroup label="<?php _e( 'v1.0 Templates', 'total_slider' ); ?>">
						<?php foreach( $legacy as $tpl ): ?>
							<option
							value="<?php echo esc_attr( $tpl['slug'] ); ?>"
							<?php if ('legacy' == $slide_group->templateLocation): ?>
								selected="selected"
								<?php endif; ?>
							><?php echo esc_html( $tpl['name'] );?></option>
						<?php endforeach; ?>
					</optgroup>								
					<?php endif; ?>										
			
					<?php //$downloaded = $t->discover_templates('downloaded'); ?>
					<?php $downloaded = false; ?>
					<?php if ( is_array( $downloaded ) && count( $downloaded ) > 0 ): ?>
					<!--<optgroup label="<?php _e( 'Downloaded', 'total_slider' );?>">
						<?php foreach( $downloaded as $tpl ): ?>
							<option
								value="<?php echo esc_attr( $tpl['slug'] ); ?>"
								<?php if ( 'downloaded' == $slide_group->templateLocation && $slideGroup->template == $tpl['slug'] ): ?>
								selected="selected"
								<?php endif; ?>
								
							><?php echo esc_html( $tpl['name'] );?></option>
						<?php endforeach; ?>																
					</optgroup>	-->
					<?php endif; ?>
													
				</select>
			<input id="template-switch-button" type="submit" class="button-secondary action" style="margin-top:8px; max-width:180px;" value="<?php _e( 'Change Template', 'total_slider' );?>" />
			</p>
		</div><?php	
		
	}

	public static function print_slide_preview_metabox() {
	/*
		Print to output the contents of the slide preview metabox.
	*/
	
		global $TS_The_Template;
	
		require( dirname( __FILE__ ) . '/admin/metaboxes/slide-preview.php' );

	}

	public static function print_slide_editor_metabox()
	{
	/*
		Print to output the contents of the slide editor metabox.
	*/

		require( dirname( __FILE__ ) . '/admin/metaboxes/slide-editor.php' );

	}

	public static function print_admin_css() {
	/*
		Print the admin CSS to show our admin menu icons.
	*/
		require( dirname( __FILE__ ) . '/admin/support/admin-css.php' );

	}


};

require_once( dirname( __FILE__ ) . '/includes/class.total-slider-widget.php' );


function total_slider_shortcode( $atts, $content, $tag ) {
	return Total_Slider::shortcode_handler( $atts, $content, $tag );
}

/******************************************** WordPress actions ********************************************/

register_activation_hook( __FILE__, array ('Total_Slider', 'create_slides_option_field' ) );
add_action( 'init', array( 'Total_Slider', 'load_text_domain' ) );
add_action('init', array( 'Total_Slider', 'bootstrap_tinymce_plugin' ) );
add_action( 'admin_menu', array( 'Total_Slider', 'add_admin_submenu' ) );
add_action( 'admin_head', array( 'Total_Slider', 'print_admin_css' ) );
add_action( 'widgets_init', array( 'Total_Slider', 'register_as_widget' ) );
add_action( 'admin_init', array( 'Total_Slider', 'pass_control_to_ajax_handler' ) );
add_action( 'admin_head-media-upload-popup', array( 'Total_Slider', 'print_uploader_javascript' ) );

add_shortcode( 'totalslider', 'total_slider_shortcode' );
